package pdf

import "testing"

// TestIsWhitespace tests the isWhitespace function.
func TestIsWhitespace(t *testing.T) {
	whitespaceChars := []rune{0x00, 0x09, 0x0A, 0x0C, 0x0D, 0x20}
	nonWhitespaceChars := []rune{'a', '1', '!', '(', ')', 'Ͱ', '￿', ' ', '　', ' '}

	// Test all valid whitespace characters.
	for _, ch := range whitespaceChars {
		if !isWhitespace(ch) {
			t.Errorf("Expected isWhitespace(%q) to be true, got false", ch)
		}
	}

	// Test some characters that are not whitespace.
	for _, ch := range nonWhitespaceChars {
		if isWhitespace(ch) {
			t.Errorf("Expected isWhitespace(%q) to be false, got true", ch)
		}
	}
}

// TestIsDelimiter tests the isDelimiter function.
func TestIsDelimiter(t *testing.T) {
	delimiterChars := []rune{'(', ')', '<', '>', '[', ']', '/', '%'}
	nonDelimiterChars := []rune{'a', '1', ' ', '!', 'x', 'Ͱ', '￿'}

	// Test all valid delimiter characters.
	for _, ch := range delimiterChars {
		if !isDelimiter(ch) {
			t.Errorf("Expected isDelimiter(%q) to be true, got false", ch)
		}
	}

	// Test some characters that are not delimiters.
	for _, ch := range nonDelimiterChars {
		if isDelimiter(ch) {
			t.Errorf("Expected isDelimiter(%q) to be false, got true", ch)
		}
	}
}

func TestIsLeftParenthesis(t *testing.T) {
	charsThatShouldBeTrue := []rune{'('}
	charsThatShouldBeFalse := []rune{')', '<', '>', '[', ']', '/', '%', 'a', '1', ' ', '!', 'x', 'Ͱ', '￿'}

	for _, ch := range charsThatShouldBeTrue {
		if !isLeftParenthesis(ch) {
			t.Errorf("Expected isLeftParenthesis(%q) to be true, got false", ch)
		}
	}

	for _, ch := range charsThatShouldBeFalse {
		if isLeftParenthesis(ch) {
			t.Errorf("Expected isLeftParenthesis(%q) to be false, got true", ch)
		}
	}
}

func TestHexToString(t *testing.T) {
	hexString := "EF BB BF E8 A1 A8 E3 83 9D E3 81 82 41 E9 B7 97 C5 92 C3 A9 EF BC A2 E9 80 8D C3 9C C3 9F C2 AA C4 85 C3 B1 E4 B8 82 E3 90 80 F0 A0 80 80"
	expected := "\ufeff表ポあA鷗ŒéＢ逍Üßªąñ丂㐀𠀀"
	result, err := hexToString(hexString)

	if err != nil {
		t.Errorf("Expected no error, got %v", err)
	}

	if result != expected {
		t.Errorf("Expected %q, got %q", expected, result)
	}
}
