package pdf

type commentToken struct {
	tokenInternal
	comment string
}

func (t *commentToken) emit() {
	// Spezifische Logik für commentToken, zusätzlich zum Standardverhalten
	t.comment = string(t.values)
	t.tokenInternal.emitFlag = true
}

// commentState represents the state of the tokenizer when processing a comment.
// A comment is a sequence of characters between a percent sign (%) and the end of the line.
// Comments are ignored by the PDF reader.
// See section 7.2.4 (Comments) of the PDF 32000-1:2008 specification.
type commentState struct {
	token *commentToken
}

func (s commentState) process(t *Tokenizer) {

	for {
		c, err := t.consumeNextRune()
		if err != nil {
			t.emitToken(s.token)
			t.raiseError(err)
			return
		}

		if isEndOfLine(c) {
			t.emitToken(s.token)

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(endOfLineState{
				token: &endOfLineToken{},
			})
			return
		}

		s.token.values = append(s.token.values, c)
	}
}
