package pdf

import (
	"io"
	"testing"
)

func TestEndArrayObjectStateProcess(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"empty", "", endArrayObjectState{}, io.EOF, []tokenInterface{}},
		{"wrong char", "x", endArrayObjectState{}, errArrayObjectMustEndWithBracket, []tokenInterface{}},
		{"end of array", "]", endArrayObjectState{}, nil, []tokenInterface{&endArrayObjectToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = endArrayObjectState{
				token: &endArrayObjectToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
