package pdf

import (
	"io"
	"testing"
)

func TestEndOfFileState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"Empty File", "", endOfFileState{}, io.EOF, []tokenInterface{}},
		{"End of file", "EOF", endOfFileState{}, io.EOF, []tokenInterface{}},
		{"End of file with end of line", "%%EOF\n", endOfLineState{}, nil, []tokenInterface{&endOfFileToken{}, &endOfLineToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = endOfFileState{
				token: &endOfFileToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}

func TestEndOfFileTokenIsNil(t *testing.T) {
	tok := createTestTokenizerWithData("2.0\r\n")
	tok.state = fileHeaderState{}

	// Verarbeite den Tokenizer
	tok.state.process(tok)

	if !tok.hasError() {
		t.Errorf("Expected error, got none")
	}
}
