package pdf

import (
	"testing"
)

func TestEndOfLineState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"End of line", "\r\n", endOfLineState{}, nil, []tokenInterface{&endOfLineToken{}}},
		{"No more end of line", " ", endOfLineState{}, nil, []tokenInterface{&endOfLineToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = endOfLineState{
				token: &endOfLineToken{},
			}

			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}

func TestEndOfLineTokenIsNil(t *testing.T) {
	tok := createTestTokenizerWithData("2.0\r\n")
	tok.state = endOfLineState{}

	// Verarbeite den Tokenizer
	tok.state.process(tok)

	if !tok.hasError() {
		t.Errorf("Expected error, got none")
	}
}
