package pdf

import (
	"strings"
)

type identifyLineTypeState struct{}

func (s identifyLineTypeState) process(t *Tokenizer) {

	buffer := ""

	for {

		c, err := t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isEndOfLine(c) {

			switch {
			case buffer == keywordStartXRef:

				err := t.unread()
				if err != nil {
					t.raiseError(err)
					return
				}

				t.switchState(readXrefOffsetState{
					token: &xrefOffsetToken{},
				})

				t.switchState(endOfFileState{
					token: &endOfFileToken{},
				})

				return

			case buffer == keywordXRef:

				err := t.unread()
				if err != nil {
					t.raiseError(err)
					return
				}

				t.switchState(readXrefState{
					token: &xrefToken{},
				})

				return

			case buffer == keywordStartTrailer:

				err := t.unread()
				if err != nil {
					t.raiseError(err)
					return
				}

				t.switchState(trailerStartState{
					token: &trailerToken{},
				})

				return
			case strings.TrimSpace(buffer) == "":

				t.switchState(endOfLineState{
					token: &endOfLineToken{},
				})
				return

			default:
				err := t.unread()
				if err != nil {
					t.raiseError(err)
					return
				}

				err = t.unreadCount(len(buffer))
				if err != nil {
					t.raiseError(err)
					return
				}

				t.switchState(readIndirectObjectState{
					token: &indirectObjectToken{},
				})

				t.switchState(endOfLineState{
					token: &endOfLineToken{},
				})
				return

			}
		}

		if isPercentSign(c) {

			eofToken := &endOfFileToken{}

			t.switchState(endOfFileState{
				token: eofToken,
			})

			if eofToken.isEmitted() {
				return
			}

			t.switchState(commentState{
				token: &commentToken{},
			})

			continue
		}

		buffer += string(c)

	}
}
