package pdf

import (
	"testing"
)

func TestIdentifyLineTypeState_Process(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"Simple Trailer example", "trailer\n<<\n/Size 22\n/Root 1 0 R\n/Info 2 0 R\n>>\nstartxref\n123456\n%%EOF\n",
			endOfLineState{},
			nil,
			[]tokenInterface{
				&trailerToken{},
				&startDictionaryObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&referenceObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&referenceObjectToken{},
				&whitespaceToken{},
				&endDictionaryObjectToken{},
				&whitespaceToken{},
				&endOfLineToken{},
				&startStartxrefToken{},
				&endOfLineToken{},
				&xrefOffsetToken{},
				&endOfLineToken{},
				&endOfFileToken{},
				&endOfLineToken{},
			}},
		{"Simple example with comment", "4 0 obj\n<<\n  /Type /Page\n  /Parent 3 0 R\n  /MediaBox [0 0 612 396]\n  /Contents [5 0 R 6 0 R]\n  /Resources <<\n    /Font << /F1 7 0 R >>\n  >>\n>>\nendobj\n",
			endOfLineState{},
			nil,
			[]tokenInterface{
				&indirectObjectToken{},
				&indirectObjectIdentifierToken{},
				&indirectObjectGenerationToken{},
				&indirectObjectKeywordToken{},
				&startDictionaryObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&referenceObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&arrayStartToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&endArrayObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&arrayStartToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&referenceObjectToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&referenceObjectToken{},
				&endArrayObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&startDictionaryObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&startDictionaryObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&referenceObjectToken{},
				&whitespaceToken{},
				&endDictionaryObjectToken{},
				&whitespaceToken{},
				&endDictionaryObjectToken{},
				&whitespaceToken{},
				&endDictionaryObjectToken{},
				&whitespaceToken{},
				&endOfLineToken{},
				&endOfIndirectObjectToken{},
				&endOfLineToken{},
			},
		},
		{"Simple example with stream", "6 0 obj\n<< /Length 165 >>\nstream\n% A text block that shows \"Hello World\"\n% No color is set, so this defaults to black in DeviceGray colorspace\nBT\n  /F1 24 Tf\n  100 100 Td\n  (Hello World) Tj\nET\nendstream\nendobj\n",
			endOfLineState{},
			nil,
			[]tokenInterface{

				&indirectObjectToken{},
				&indirectObjectIdentifierToken{},
				&indirectObjectGenerationToken{},
				&indirectObjectKeywordToken{},
				&startDictionaryObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&endDictionaryObjectToken{},
				&whitespaceToken{},
				&endOfLineToken{},
				&startStreamObjectToken{},
				&streamObjectToken{},
				&endStreamObjectToken{},
				&endOfIndirectObjectToken{},
				&endOfLineToken{},
			},
		},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = identifyLineTypeState{}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
