package pdf

import (
	"io"
	"testing"
)

func TestInitialStateProcess(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"Percent sign with version", "%PDF-2.0\r\n ", identifyLineTypeState{}, io.EOF, []tokenInterface{&fileHeaderToken{}, &pdfVersionToken{}, &endOfLineToken{}}},
		{"Percent sign with version with prefix", "xy123xs%PDF-2.0\r\n ", identifyLineTypeState{}, io.EOF, []tokenInterface{&fileHeaderToken{}, &pdfVersionToken{}, &endOfLineToken{}}},
		{"Percent sign with version", "%PDF-2.0", pdfVersionState{}, io.EOF, []tokenInterface{&fileHeaderToken{}, &pdfVersionToken{}}},
		{"Percent sign with version and Prefix Spaces", "   %PDF-2.0", pdfVersionState{}, io.EOF, []tokenInterface{&fileHeaderToken{}, &pdfVersionToken{}}},
		{"No percent, EOF", "Some random text", initialState{}, io.EOF, []tokenInterface{}},
		{"Find percent sign without version", "   %PDF-", fileHeaderState{}, io.EOF, []tokenInterface{}},
		{"Empty input", "", initialState{}, io.EOF, []tokenInterface{}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = initialState{}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
