package pdf

import (
	"io"
	"testing"
)

func TestPdfVersionState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"PDF Version 2.0 with an end of line", "2.0\r\n", endOfLineState{}, nil, []tokenInterface{&pdfVersionToken{}, &endOfLineToken{}}},
		{"PDF Version 1.0", "1.0", pdfVersionState{}, io.EOF, []tokenInterface{&pdfVersionToken{}}},
		{"PDF Version 2.0", "2.0", pdfVersionState{}, io.EOF, []tokenInterface{&pdfVersionToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = pdfVersionState{
				token: &pdfVersionToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
