package pdf

import (
	"io"
	"testing"
)

func TestReadBooleanObjectStateProcess(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"empty", "", readBooleanObjectState{}, io.EOF, []tokenInterface{}},
		{"true", "true", readBooleanObjectState{}, io.EOF, []tokenInterface{}},
		{"false", "false", readBooleanObjectState{}, io.EOF, []tokenInterface{}},
		{"false space", "false ", readBooleanObjectState{}, nil, []tokenInterface{&booleanToken{}}},
		{"true space", "true ", readBooleanObjectState{}, nil, []tokenInterface{&booleanToken{}}},
		{"wrong tru", "tru", readBooleanObjectState{}, io.EOF, []tokenInterface{}},
		{"wrong ta", "ta", readBooleanObjectState{}, io.EOF, []tokenInterface{}},
		{"wrong ta", "t ", readBooleanObjectState{}, ErrInvalidBoolean, []tokenInterface{}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = readBooleanObjectState{
				token: &booleanToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
