package pdf

type indirectObjectToken struct {
	tokenInternal
}

type readIndirectObjectState struct {
	token *indirectObjectToken
}

func (s readIndirectObjectState) process(t *Tokenizer) {

	var c rune
	var err error

	for {

		c, err = t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		switch {
		case isWhitespace(c):

			t.switchState(whitespaceState{
				token: &whitespaceToken{},
			})

		case isNumeric(c):

			t.emitToken(s.token)

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			p, err := t.peekNextRune()
			if err != nil {
				t.raiseError(err)
				return
			}

			if isWhitespace(p) {
				t.switchState(whitespaceState{
					token: &whitespaceToken{},
				})
			}

			t.switchState(readIndirectObjectIdentifierState{
				token: &indirectObjectIdentifierToken{},
			})

			for {
				p, err = t.peekNextRune()
				if err != nil {
					t.raiseError(err)
					return
				}

				if isWhitespace(p) {
					t.switchState(whitespaceState{
						token: &whitespaceToken{},
					})
				}

				t.switchState(startValueState{})

				p, err = t.peekNextRune()
				if err != nil {
					t.raiseError(err)
					return
				}

				if isWhitespace(p) {
					t.switchState(whitespaceState{
						token: &whitespaceToken{},
					})
				}

				t.switchState(endOfIndirectObjectState{
					token: &endOfIndirectObjectToken{},
				})

				p := *t.peekToken()
				if p == nil {
					t.raiseError(ErrUnexpectedNullToken)
					return
				}

				if _, ok := p.(*endOfIndirectObjectToken); ok {
					return
				}

				t.removeLastError()

			}

		default:
			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}
			t.raiseError(ErrInvalidIndirectObjectIdentifier)
			return
		}

	}

}
