package pdf

import "strconv"

type indirectObjectGenerationToken struct {
	tokenInternal
	value int
}

type readIndirectObjectGenerationState struct {
	token *indirectObjectGenerationToken
}

func (s readIndirectObjectGenerationState) process(t *Tokenizer) {

	var c rune
	var err error

	generation := ""

	for {
		c, err = t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isEndOfLine(c) {
			t.raiseError(ErrUnexpectedEndOfLine)
			return
		}

		if isWhitespace(c) {

			v, err := strconv.Atoi(generation)
			if err != nil {
				t.raiseError(err)
				return
			}
			s.token.value = v
			t.emitToken(s.token)
			t.switchState(readIndirectObjectKeywordState{
				token: &indirectObjectKeywordToken{},
			})
			return
		}

		if !isNumeric(c) {
			t.raiseError(ErrInvalidIndirectObjectGeneration)
			return
		}

		generation += string(c)

	}

}
