package pdf

import (
	"io"
	"testing"
)

func TestReadIndirectObjectGenerationState_Process(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
		expectedValue int
	}{
		{"empty", "", readIndirectObjectGenerationState{}, io.EOF, []tokenInterface{}, 0},
		{"Generation", "12", readIndirectObjectGenerationState{}, io.EOF, []tokenInterface{}, 0},
		{"Generation with space", "12 obj ", readIndirectObjectKeywordState{}, nil, []tokenInterface{&indirectObjectGenerationToken{}, &indirectObjectKeywordToken{}}, 12},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = readIndirectObjectGenerationState{
				token: &indirectObjectGenerationToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

			if tt.expectedValue > 0 {
				st, ok := tok.tokenStack[0].(*indirectObjectGenerationToken)
				if !ok {
					t.Errorf("state is not readIndirectObjectGenerationState")
					return
				}

				if st.value != tt.expectedValue {
					t.Errorf("expected value %d, got %d", tt.expectedValue, st.value)
				}
			}
		})
	}
}
