package pdf

import (
	"io"
	"testing"
)

func TestReadIndirectObjectIdentifierState_Process(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
		expectedValue int
	}{
		{"empty", "", readIndirectObjectIdentifierState{}, io.EOF, []tokenInterface{}, 0},
		{"ID", "12", readIndirectObjectIdentifierState{}, io.EOF, []tokenInterface{}, 0},
		{"ID with space", "23 12 obj ", readIndirectObjectKeywordState{}, nil,
			[]tokenInterface{
				&indirectObjectIdentifierToken{},
				&indirectObjectGenerationToken{},
				&indirectObjectKeywordToken{}},
			23},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = readIndirectObjectIdentifierState{
				token: &indirectObjectIdentifierToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

			if tt.expectedValue > 0 {
				st, ok := tok.tokenStack[0].(*indirectObjectIdentifierToken)
				if !ok {
					t.Errorf("state is not readIndirectObjectIdentifierState")
					return
				}

				if st.value != tt.expectedValue {
					t.Errorf("expected value %d, got %d", tt.expectedValue, st.value)
				}
			}
		})
	}
}
