package pdf

import (
	"io"
	"testing"
)

func TestReadIndirectObjectKeywordState_Process(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
		expectedValue string
	}{
		{"empty", "", readIndirectObjectKeywordState{}, io.EOF, []tokenInterface{}, ""},
		{"obj keyword", "obj", readIndirectObjectKeywordState{}, io.EOF, []tokenInterface{}, ""},
		{"obj keyword with space", "obj ", readIndirectObjectKeywordState{}, nil, []tokenInterface{&indirectObjectKeywordToken{}}, "obj"},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = readIndirectObjectKeywordState{
				token: &indirectObjectKeywordToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

			if len(tt.expectTokens) > 0 {
				st, ok := tok.state.(readIndirectObjectKeywordState)
				if !ok {
					t.Errorf("state is not readNameObjectState")
					return
				}

				if st.token.value != tt.expectedValue {
					t.Errorf("expected value %s, got %s", tt.expectedValue, st.token.value)
				}
			}

		})
	}
}
