package pdf

import (
	"io"
	"testing"
)

func TestIndirectObjectState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
		expectedID    int
		expectedGen   int
		expectedType  string
	}{
		{"empty", "", readIndirectObjectState{}, io.EOF, []tokenInterface{}, 0, 0, ""},
		{"Example from Documentation 7.3.10", "12 0 obj\n(Brillig)\nendobj ", endOfIndirectObjectState{}, nil,
			[]tokenInterface{
				&indirectObjectToken{},
				&indirectObjectIdentifierToken{},
				&indirectObjectGenerationToken{},
				&indirectObjectKeywordToken{},
				&stringToken{},
				&whitespaceToken{},
				&endOfLineToken{},
				&endOfIndirectObjectToken{},
			}, 12, 0, "obj"},
		{"Example from Simple PDF File", "8 0 obj\n[ 278 556\n  556 1015\n  667 667\n  778 222\n  556 56\n  556 584 ]\nendobj\n\n",
			endOfIndirectObjectState{},
			nil, []tokenInterface{
				&indirectObjectToken{},
				&indirectObjectIdentifierToken{},
				&indirectObjectGenerationToken{},
				&indirectObjectKeywordToken{},
				&arrayStartToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&endArrayObjectToken{},
				&whitespaceToken{},
				&endOfLineToken{},
				&endOfIndirectObjectToken{},
			}, 0, 0, ""},
		{"Example from Simple PDF File", "1 0 obj\n<<\n  /Type /Catalog\n  /Lang (en-UK) % Default language\n\n>>\nendobj\n",
			endOfIndirectObjectState{},
			nil, []tokenInterface{

				&indirectObjectToken{},
				&indirectObjectIdentifierToken{},
				&indirectObjectGenerationToken{},
				&indirectObjectKeywordToken{},
				&startDictionaryObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&stringToken{},
				&whitespaceToken{},
				&commentToken{},
				&endOfLineToken{},
				&whitespaceToken{},
				&endDictionaryObjectToken{},
				&whitespaceToken{},
				&endOfLineToken{},
				&endOfIndirectObjectToken{},
			}, 1, 0, "obj"},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = readIndirectObjectState{
				token: &indirectObjectToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
