package pdf

import (
	"io"
	"testing"
)

func TestReadNullObjectStateProcess(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"empty", "", readNullObjectState{}, io.EOF, []tokenInterface{}},
		{"null", "null", readNullObjectState{}, io.EOF, []tokenInterface{}},
		{"null", "null ", readNullObjectState{}, nil, []tokenInterface{&nullToken{}}},
		{"null", "nu", readNullObjectState{}, io.EOF, []tokenInterface{}},
		{"null", "nu ", readNullObjectState{}, ErrInvalidNull, []tokenInterface{}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = readNullObjectState{
				token: &nullToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
