package pdf

import (
	"io"
	"testing"
)

func TestReadStreamObjectStat_Process(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"empty", "", readStreamObjectState{}, io.EOF, []tokenInterface{}},
		{"example from documentation", "BT\n/F1 12 Tf\n72 712 Td\n(A stream with an indirect length) Tj\nET\nendstream",
			endStreamObjectState{}, nil, []tokenInterface{&streamObjectToken{}, &endStreamObjectToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = readStreamObjectState{
				token: &streamObjectToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
