package pdf

type xrefToken struct {
	tokenInternal
}

type xrefStateToken struct {
	tokenInternal
	value rune
}

type readXrefState struct {
	token *xrefToken
}

func (s readXrefState) process(t *Tokenizer) {

	var c rune
	var err error

	for {

		c, err = t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		switch {
		case isEndOfLine(c):
			t.switchState(endOfLineState{
				token: &endOfLineToken{},
			})
			continue

		case isWhitespace(c):

			t.switchState(whitespaceState{
				token: &whitespaceToken{},
			})
			continue

		case isNumeric(c):
			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(readNumberObjectState{
				token: &numberToken{},
			})

			continue

		case c == 'n' || c == 'f':
			t.emitToken(&xrefStateToken{
				value: c,
			})

		case c == 't':
			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}
			t.emitToken(s.token)
			return
		}
	}

}
