package pdf

type arrayStartToken struct {
	tokenInternal
}

type startArrayObjectState struct {
	token *arrayStartToken
}

func (s startArrayObjectState) process(t *Tokenizer) {
	var c rune
	var err error

	c, err = t.consumeNextRune()
	if err != nil {
		t.raiseError(err)
		return
	}

	if !isLeftSquareBracket(c) {
		t.raiseError(errArrayObjectMustStartWithBracket)
		return
	}

	t.emitToken(s.token)

	for {
		c, err = t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isRightSquareBracket(c) {

			err = t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(endArrayObjectState{
				token: &endArrayObjectToken{},
			})
			return
		}

		// Handle whitespace and delimiters
		if isWhitespace(c) {
			t.switchState(whitespaceState{
				token: &whitespaceToken{},
			})
			continue
		}

		err = t.unread()
		if err != nil {
			t.raiseError(err)
			return
		}

		t.switchState(startValueState{})

	}

}
