package pdf

type startDictionaryObjectToken struct {
	tokenInternal
}

type startDictionaryObjectState struct {
	token *startDictionaryObjectToken
}

func (s startDictionaryObjectState) process(t *Tokenizer) {

	var r []rune
	var err error
	var c rune

	r, err = t.consumeNextRunes(2)
	if err != nil {
		t.raiseError(err)
		return
	}
	if len(r) != 2 || !isLessThanSign(r[0]) || !isLessThanSign(r[1]) {
		t.raiseError(errDictionaryObjectMustStartWithDoubleLessThanSign)
		return

	}

	t.emitToken(s.token)

	for {
		c, err = t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isGreaterThanSign(c) {
			c, err = t.consumeNextRune()
			if err != nil {
				t.raiseError(err)
				return
			}

			err := t.unreadCount(2)
			if err != nil {
				t.raiseError(err)
				return
			}

			if isGreaterThanSign(c) {
				t.switchState(endDictionaryObjectState{
					token: &endDictionaryObjectToken{},
				})
				return
			}

		}

		if isWhitespace(c) {
			t.switchState(whitespaceState{
				token: &whitespaceToken{},
			})
			continue
		}

		err = t.unread()
		if err != nil {
			t.raiseError(err)
			return
		}
		t.switchState(startValueState{})
	}
}
