package pdf

import (
	"io"
	"testing"
)

func TestStartDictionaryState_Process(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"No end of line", "x", startDictionaryObjectState{}, io.EOF, []tokenInterface{}},
		{"Example from Documentation 7.3.7", "<</Type /Example\n/Subtype /DictionaryExample\n/Version 0.01\n/IntegerItem 12\n/StringItem (a string)\n/Subdictionary <<\n/Item1 0.4\n/Item2 true\n/LastItem (not !)\n/VeryLastItem (OK)\n>>\n>>", endDictionaryObjectState{}, nil, []tokenInterface{
			&startDictionaryObjectToken{},
			&nameToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&numberToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&numberToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&stringToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&startDictionaryObjectToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&numberToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&booleanToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&stringToken{},
			&whitespaceToken{},
			&nameToken{},
			&whitespaceToken{},
			&stringToken{},
			&whitespaceToken{},
			&endDictionaryObjectToken{},
			&whitespaceToken{},
			&endDictionaryObjectToken{},
		}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = startDictionaryObjectState{
				token: &startDictionaryObjectToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
