package pdf

import (
	"io"
	"testing"
)

func TestStartStartXrefState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"empty", "", startStartXrefState{}, io.EOF, []tokenInterface{}},
		{"startxref 1", "startxref", startStartXrefState{}, io.EOF, []tokenInterface{}},
		{"startxref 2", "startxref\n123456\n ", endOfLineState{}, nil, []tokenInterface{
			&startStartxrefToken{},
			&endOfLineToken{},
			&xrefOffsetToken{},
			&endOfLineToken{},
		}},
		{"startxref 3", "st", startStartXrefState{}, io.EOF, []tokenInterface{}},
		{"startxref 4", "st ", startStartXrefState{}, ErrInvalidStartXref, []tokenInterface{}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = startStartXrefState{
				token: &startStartxrefToken{},
			}

			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
