package pdf

import (
	"io"
	"testing"
)

func TestStartStreamObjectStat_Process(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"empty", "", startStreamObjectState{}, io.EOF, []tokenInterface{}},
		{"example from documentation", "stream\nBT\n/F1 12 Tf\n72 712 Td\n(A stream with an indirect length) Tj\nET\nendstream",
			endStreamObjectState{}, nil, []tokenInterface{&startStreamObjectToken{}, &streamObjectToken{}, &endStreamObjectToken{}}},
		{"example from simple-pdf 2.0", "stream\n<x:xmpmeta xmlns:x='adobe:ns:meta/' x:xmptk='Insert XMP tool name here.'>\n  <rdf:RDF xmlns:rdf='http://www.w3.org/1999/02/22-rdf-syntax-ns#'>\n    <rdf:Description rdf:about=\"\" xmlns:pdf=\"http://ns.adobe.com/pdf/1.3/\">\n      <pdf:Producer>Datalogics - example producer program name here</pdf:Producer>\n      <pdf:Copyright>Copyright 2017 PDF Association</pdf:Copyright>\n      <pdf:Keywords>PDF 2.0 sample example</pdf:Keywords>\n    </rdf:Description>\n    <rdf:Description rdf:about=\"\" xmlns:xap=\"http://ns.adobe.com/xap/1.0/\">\n      <xap:CreateDate>2017-05-24T10:30:11Z</xap:CreateDate>\n      <xap:MetadataDate>2017-07-11T07:55:11Z</xap:MetadataDate>\n      <xap:ModifyDate>2017-07-11T07:55:11Z</xap:ModifyDate>\n      <xap:CreatorTool>Datalogics - example creator tool name here</xap:CreatorTool>\n    </rdf:Description>\n    <rdf:Description rdf:about=\"\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\">\n      <dc:format>application/pdf</dc:format>\n      <dc:title>\n        <rdf:Alt>\n          <rdf:li xml:lang=\"x-default\">A simple PDF 2.0 example file</rdf:li>\n        </rdf:Alt>\n      </dc:title>\n      <dc:creator>\n        <rdf:Seq>\n          <rdf:li>Datalogics Incorporated</rdf:li>\n        </rdf:Seq>\n      </dc:creator>\n      <dc:description>\n        <rdf:Alt>\n          <rdf:li xml:lang=\"x-default\">Demonstration of a simple PDF 2.0 file.</rdf:li>\n        </rdf:Alt>\n      </dc:description>\n      <dc:rights>\n        <rdf:Alt>\n          <rdf:li xml:lang=\"x-default\">Copyright 2017 PDF Association. Licensed to the public under Creative Commons Attribution-ShareAlike 4.0 International license.</rdf:li>\n        </rdf:Alt>\n      </dc:rights>\n    </rdf:Description>\n    <rdf:Description rdf:about=\"\" xmlns:xapRights=\"http://ns.adobe.com/xap/1.0/rights/\">\n      <xapRights:Marked>True</xapRights:Marked>\n    </rdf:Description>\n    <rdf:Description rdf:about=\"\" xmlns:cc=\"http://creativecommons.org/ns#\">\n      <cc:license rdf:resource=\"https://creativecommons.org/licenses/sa/4.0/\" />\n    </rdf:Description>\n    <rdf:Description rdf:about=\"\" xmlns:xapMM=\"http://ns.adobe.com/xap/1.0/mm/\">\n      <xapMM:DocumentID>uuid:3eef2166-8332-abb4-3d31-77334578873f</xapMM:DocumentID>\n      <xapMM:InstanceID>uuid:991bcce7-ee70-11a3-91aa-77bbe2181fd8</xapMM:InstanceID>\n    </rdf:Description>\n  </rdf:RDF>\n</x:xmpmeta>\nendstream\n",
			endStreamObjectState{}, nil, []tokenInterface{&startStreamObjectToken{}, &streamObjectToken{}, &endStreamObjectToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = startStreamObjectState{
				token: &startStreamObjectToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
