package pdf

type startValueState struct {
}

func (s startValueState) process(t *Tokenizer) {

	for {

		c, err := t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		// Bestimme den Typ basierend auf der ersten Nicht-Whitespace-Rune
		switch {

		case isPercentSign(c):

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(commentState{
				token: &commentToken{},
			})
			return

		case isNumeric(c) || c == '+' || c == '-':
			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(readNumberObjectState{
				token: &numberToken{},
			})
			return

		case isLeftParenthesis(c):
			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(readStringObjectState{
				token: &stringToken{},
			})
			return
		case isLessThanSign(c):

			x, err := t.consumeNextRune()
			if err != nil {
				t.raiseError(err)
				return
			}

			err = t.unreadCount(2)
			if err != nil {
				t.raiseError(err)
				return
			}

			if isLessThanSign(x) {

				t.switchState(startDictionaryObjectState{
					token: &startDictionaryObjectToken{},
				})

				return
			}

			t.switchState(readStringObjectState{
				token: &stringToken{},
			})

			return
		case isSolidus(c):

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(readNameObjectState{
				token: &nameToken{},
			})
			return

		case isLeftSquareBracket(c):

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(startArrayObjectState{
				token: &arrayStartToken{},
			})
			return

		case c == 't' || c == 'f':

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(readBooleanObjectState{
				token: &booleanToken{},
			})
			return

		case c == 'n':

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(readNullObjectState{
				token: &nullToken{},
			})
			return

		case c == 'R':
			err := t.unread()

			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(readReferenceObjectState{
				token: &referenceObjectToken{},
			})
			return

		case isWhitespace(c): // array or dictionary may contain whitespace
			return

		case c == 's':

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(startStreamObjectState{
				token: &startStreamObjectToken{},
			})

		default:
			t.raiseError(ErrUnknownValueType)
			return
		}

	}
}
