package pdf

import (
	"io"
	"testing"
)

func TestStartXrefState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"empty", "", startXrefState{}, io.EOF, []tokenInterface{}},

		{"xref from the simple sample file", "xref\n0 10\n0000000000 65535 f\n0000000016 00000 n\n0000000096 00000 n\n0000002547 00000 n\n0000002619 00000 n\n0000002782 00000 n\n0000003587 00000 n\n0000003811 00000 n\n0000003972 00000 n\n0000004524 00000 n\ntrailer",
			endOfLineState{}, nil, []tokenInterface{

				&startXrefToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&xrefStateToken{},
				&endOfLineToken{},
				&xrefToken{},
			}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = startXrefState{
				token: &startXrefToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
