package pdf

import (
	"errors"
	"reflect"
	"testing"
)

func checkStateAgainstDef(t *testing.T, tok *Tokenizer, expectedState state) {
	if reflect.TypeOf(tok.state) != reflect.TypeOf(expectedState) {
		t.Errorf("expected state to be %T, got %T", expectedState, tok.state)
	}
}

func checkTokenAgainstDef(t *testing.T, actualToken tokenInterface, expectedToken tokenInterface) {
	if reflect.TypeOf(actualToken) != reflect.TypeOf(expectedToken) {
		t.Errorf("expected token to be %T, got %T", expectedToken, actualToken)
	}
}

func containsError(errs []error, targetError error) bool {
	for _, err := range errs {
		if errors.Is(err, targetError) {
			return true
		}
	}
	return false
}

func checkErrors(t *testing.T, tok *Tokenizer, expectedError error) {
	errs := tok.Errors()

	if len(errs) == 0 && expectedError == nil {
		// no error
	} else if len(errs) == 0 && expectedError != nil {
		t.Errorf("expected error %v, got %v", expectedError, errs)
	} else if len(errs) > 0 && expectedError == nil {
		t.Errorf("expected no error, got %v", errs)
	} else {
		if !containsError(errs, expectedError) {
			t.Errorf("expected error %v, got %v", expectedError, errs)
		}
	}
}

func checkTokenStack(t *testing.T, tok *Tokenizer, expectedTokens []tokenInterface) {
	// check token
	if len(expectedTokens) > 0 {
		for i, token := range expectedTokens {
			if len(tok.tokenStack) < i+1 {
				t.Errorf("expected token %v, got %v", token, tok.tokenStack)
				continue
			}

			tx := tok.tokenStack[i]

			checkTokenAgainstDef(t, tx, token)

		}
	}

	if len(tok.tokenStack) != len(expectedTokens) {

		expectedTokenTypes := make([]string, len(expectedTokens))
		for i, token := range expectedTokens {
			expectedTokenTypes[i] = reflect.TypeOf(token).String()
		}

		gotTokenTypes := make([]string, len(tok.tokenStack))
		for i, token := range tok.tokenStack {
			gotTokenTypes[i] = reflect.TypeOf(token).String()
		}

		t.Errorf("expected %d tokens of type %v, got %d tokens of type %v", len(expectedTokens), expectedTokenTypes, len(tok.tokenStack), gotTokenTypes)
	}
}
