package pdf

type trailerToken struct {
	tokenInternal
}

type trailerStartState struct {
	token *trailerToken
}

func (s trailerStartState) process(t *Tokenizer) {

	_, err := t.consumeNextRune()
	if err != nil {
		t.raiseError(err)
		return
	}

	t.emitToken(s.token)

	for {

		c, err := t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isEndOfLine(c) {
			continue
		}

		switch {
		case isLessThanSign(c):

			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(startDictionaryObjectState{
				token: &startDictionaryObjectToken{},
			})

			c, err = t.consumeNextRune()
			if err != nil {
				t.raiseError(err)
				return
			}

			err = t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			if isWhitespace(c) {

				t.switchState(whitespaceState{
					token: &whitespaceToken{},
				})
			}

			t.switchState(startStartXrefState{
				token: &startStartxrefToken{},
			})

			c, err = t.consumeNextRune()
			if err != nil {
				t.raiseError(err)
				return
			}

			err = t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			if isWhitespace(c) {

				t.switchState(whitespaceState{
					token: &whitespaceToken{},
				})
			}

			t.switchState(endOfFileState{
				token: &endOfFileToken{},
			})

			return

		}

		//if startDict == keywordStartDictionary {
		//	return
		//}

	}

}
