package pdf

import (
	"io"
	"testing"
)

func TestTrailerStartState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"Only whitespaces", "   ", trailerStartState{}, io.EOF, []tokenInterface{&trailerToken{}}},
		{"Simple Trailer example", "trailer\n<<\n/Size 22\n/Root 1 0 R\n/Info 2 0 R\n>>\nstartxref\n123456\n%%EOF\n",
			endOfLineState{}, nil,
			[]tokenInterface{

				&trailerToken{},
				&startDictionaryObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&referenceObjectToken{},
				&whitespaceToken{},
				&nameToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&numberToken{},
				&whitespaceToken{},
				&referenceObjectToken{},
				&whitespaceToken{},
				&endDictionaryObjectToken{},
				&whitespaceToken{},
				&endOfLineToken{},
				&startStartxrefToken{},
				&endOfLineToken{},
				&xrefOffsetToken{},
				&endOfLineToken{},
				&endOfFileToken{},
				&endOfLineToken{},
			}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = trailerStartState{
				token: &trailerToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
