package pdf

import (
	"io"
	"testing"
)

func TestWhitespaceState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"Only whitespaces", "   ", whitespaceState{}, io.EOF, []tokenInterface{&whitespaceToken{}}},
		{"Whitespaces followed by a", "   a", whitespaceState{}, nil, []tokenInterface{&whitespaceToken{}}},
		{"Empty Input", "", whitespaceState{}, io.EOF, []tokenInterface{&whitespaceToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = whitespaceState{
				token: &whitespaceToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
